@@ -26,10 +26,18 @@ from load_shedding.providers.eskom import Province, Stage, Suburb, Provider, Pro
 CACHE_TTL: Final = 86400
 
 
-class ScheduleError(Exception):
+class StageError(Exception):
     pass
 
 
+def get_stage(provider: Provider) -> Stage:
+    try:
+        stage = provider.get_stage()
+    except ProviderError as e:
+        raise StageError(f"Unable to get stage from {provider}") from e
+    return stage
+
+
 def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage: Stage = None, cached: bool = True) -> List: # Dict[Stage, list]:
     now = datetime.now(timezone.utc)
     try:
@@ -39,14 +47,10 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
             raise
 
     if stage in [None, Stage.UNKNOWN]:
-        try:
-            stage = provider.get_stage()
-        except ProviderError as e:
-            logging.log(logging.ERROR, "Unable to get stage from {provider}. {e}".format(provider=provider, e=e))
-            raise
+        stage = get_stage(provider)
 
     if stage in [None, Stage.UNKNOWN, Stage.NO_LOAD_SHEDDING]:
-        raise ScheduleError("{stage}".format(stage=Stage.NO_LOAD_SHEDDING))
+        raise StageError(f"{Stage.NO_LOAD_SHEDDING}")
 
     cached_schedules = {}
     cached_schedule = []
@@ -68,12 +72,12 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
             if (now - updated_at).seconds < CACHE_TTL:
                 return cached_schedule.get("schedule", {})
     except FileNotFoundError as e:
-        logging.log(logging.ERROR, "Unable to get schedule from cache. {e}".format(e=e))
+        logging.log(logging.DEBUG, "Unable to get schedule from cache. {e}".format(e=e))
 
     try:
         schedule = provider.get_schedule(province=province, suburb=suburb, stage=stage)
     except ProviderError as e:
-        logging.log(logging.ERROR, "Unable to get schedule from {provider}. {e}".format(provider=provider, e=e))
+        logging.log(logging.DEBUG, "Unable to get schedule from {provider}. {e}".format(provider=provider, e=e))
         if cached_schedule:
             return cached_schedule  # best effort
         raise
@@ -95,12 +99,6 @@ def list_to_dict(schedule: list) -> Dict:
         start = datetime.fromisoformat(item[0])
         end = datetime.fromisoformat(item[1])
 
-        # schedule_dict[start.strftime("%Y-%m-%d")] = (
-        #     now.replace(month=start.month, day=start.day, hour=start.hour, minute=start.minute, microsecond=0).strftime(
-        #         "%H:%M"),
-        #     now.replace(month=end.month, day=end.day, hour=end.hour, minute=end.minute, microsecond=0).strftime(
-        #         "%H:%M"),
-        # )
     schedule_dict[start.strftime("%Y-%m-%d")] = (
         start.replace(second=now.second).strftime("%H:%M"),
         end.replace(second=now.second).strftime("%H:%M"),
