@@ -71,12 +71,8 @@ class Municipality(Municipality):
 
 
 class Eskom(Provider):
-    def __init__(self):
-        self.base_url = "https://loadshedding.eskom.co.za/LoadShedding"
-
-    @staticmethod
-    def name() -> str:
-        return "Eskom"
+    name = "Eskom"
+    base_url = "https://loadshedding.eskom.co.za/LoadShedding"
 
     @classmethod
     def province_from_name(cls, name: str) -> Province:
@@ -100,13 +96,13 @@ class Eskom(Provider):
     @classmethod
     def call(cls, url: str) -> Any:
         try:
-            retries = urllib3.Retry()
+            retries = urllib3.Retry(total=3)
             with urllib3.PoolManager(retries=retries, ca_certs=certifi.where()) as conn:
                 r = conn.request('GET', url)
                 if r.status != 200:
                     raise urllib3.response.HTTPError(r.status)
                 return r.data
-        except urllib3.exceptions.HTTPError as e:
+        except Exception as e:
             raise ProviderError("Eskom is unavailable.") from e
 
     @classmethod
